@@ -724,6 +724,13 @@ class VariableClCifsVer(ReadonlyVariable):
         return readFile("/sys/module/cifs/version")
 
 
+class VariableClCifsCache(Variable):
+    """
+    Параметр cache= при монтировании cifs
+    """
+    value = "loose"
+
+
 class VariableClRsyncVer(ReadonlyVariable):
     """
     Версия rsync
